/*  File: mod-jets.cc
 *  Project: Deductor
 *  Created by Zoltán Nagy on 9/8/13.
 *  Modified by D. Soper on 21 November 2014.
 *  Kernel changed to LHC-13TeV on 5 February 2016.
 *  Modified by D. Soper on 25 July 2017.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*   Deductor headers  */
#include <deductor.h>
#include <proc-hhcjets.h>

/*   Analyser headers  */
//#include "analyzer-lhe.h"
#include "analyzer-gap.h"


auto my_jet_module(const deductor_input&)
{
  /*  Using a previously creating the kernel   */
  deductor<hhc,ordering::kT> kernel{qcd::ct14n};
  
  /*    Hard process     */
  auto hard = [=](const model_ref& mdl) -> hhcjets
  {
    int proton = 2212;
    double Ecm = 7.0_TeV;
    double scalefacpert = 0.707;
    double scalefacshowerstart = 1.0;
    auto pTlist = {15.0, 40.0, 80.0, 150.0, 200.0, 250.0, 300.0, 350.0,
      400.0, 450.0, 500.0, 600.0};
    return {mdl, Ecm, pTlist, scalefacpert, scalefacshowerstart, proton, proton};
  };
  
  /*   Jet definition    */
  fj::JetDefinition jetDef{fj::antikt_algorithm, 0.6};
  
  /*   Jet cross section pT distribution */
  UserGap *JetsGap = new UserGap{"Jets", jetDef};

  /* Create the shower process, start the calculation.   */
  shower_engine_opts opts;
  opts.max_color_suppression = 4u;       // The default is 0u.
  opts.allow_color_branching = false;     // The default is true.
  
  kernel("Jets-gaps-anti-kT-R06-withKT", opts, hard, {JetsGap});
  cout << "Calculation started." << endl;
}


/*   Always export your module functions!   */
export_my_module jets_module = {
  {"Jets-7TeV", my_jet_module}
};







